# Sam Optravil

Python библиотека для сервиса Sam Optravil.

[Официальный сайт](https://samotpravil.ru/)

[Подробная документация REST API](https://documentation.samotpravil.ru/view/26779685/2s93RZM9in)

Библиотека является оберткой для API методов

## Установка

```bash
pip install samotpravil-smtp
